@@ -6,6 +6,7 @@
 #include <sstream>
 #include <list>
 #include <queue>
+#include <algorithm>
 #include "transterm.h"
 #include "seq.h"
 #include "ermolaeva-score.h"
@@ -52,11 +53,11 @@ inline
 bool
 check_tail(char letter, SeqPtr cp)
 {
-    return cp[0] == letter && cp[1] == letter && cp[2] == letter ||
-           cp[1] == letter && cp[2] == letter && cp[3] == letter ||
-           cp[2] == letter && cp[3] == letter && cp[4] == letter ||
-           cp[3] == letter && cp[4] == letter && cp[5] == letter ||
-           cp[4] == letter && cp[5] == letter && cp[6] == letter;
+    return (cp[0] == letter && cp[1] == letter && cp[2] == letter) ||
+           (cp[1] == letter && cp[2] == letter && cp[3] == letter) ||
+           (cp[2] == letter && cp[3] == letter && cp[4] == letter) ||
+           (cp[3] == letter && cp[4] == letter && cp[5] == letter) ||
+           (cp[4] == letter && cp[5] == letter && cp[6] == letter);
 }
 
 
